# -*- extra stuff goes here -*-
from contactworkplaceandworktitle import IContactworkplaceandworktitle
from contactphonenumber import IContactphonenumber
from contactemailaddress import IContactemailaddress
from contactnetaddress import IContactnetaddress
from contact import IContact
